@@ -25,7 +25,6 @@ except ImportError:
 
 from .compat import basestring, byte_type, decode_from_bytes, encode_to_bytes, text_type
 from .utils import (
-    SSL_PROTOCOL,
     MocketMode,
     MocketSocketCore,
     get_mocketize,
@@ -48,14 +47,6 @@ try:  # pragma: no cover
 except ImportError:
     pyopenssl_override = False
 
-try:  # pragma: no cover
-    from aiohttp import TCPConnector
-
-    aiohttp_make_ssl_context_cache_clear = TCPConnector._make_ssl_context.cache_clear
-except (ImportError, AttributeError):
-    aiohttp_make_ssl_context_cache_clear = None
-
-
 true_socket = socket.socket
 true_create_connection = socket.create_connection
 true_gethostbyname = socket.gethostbyname
@@ -64,7 +55,7 @@ true_getaddrinfo = socket.getaddrinfo
 true_socketpair = socket.socketpair
 true_ssl_wrap_socket = getattr(
     ssl, "wrap_socket", None
-)  # in Py3.12 it's only under SSLContext
+)  # from Py3.12 it's only under SSLContext
 true_ssl_socket = ssl.SSLSocket
 true_ssl_context = ssl.SSLContext
 true_inet_pton = socket.inet_pton
@@ -83,6 +74,7 @@ class SuperFakeSSLContext:
     minimum_version = FakeSetter()
     options = FakeSetter()
     verify_mode = FakeSetter()
+    verify_flags = FakeSetter()
 
 
 class FakeSSLContext(SuperFakeSSLContext):
@@ -102,23 +94,12 @@ class FakeSSLContext(SuperFakeSSLContext):
         return self._check_hostname
 
     @check_hostname.setter
-    def check_hostname(self, *args):
+    def check_hostname(self, _):
         self._check_hostname = False
 
-    def __init__(self, sock=None, server_hostname=None, _context=None, *args, **kwargs):
+    def __init__(self, *args, **kwargs):
         self._set_dummy_methods()
 
-        if isinstance(sock, MocketSocket):
-            self.sock = sock
-            self.sock._host = server_hostname
-            self.sock.true_socket = true_ssl_socket(
-                sock=self.sock.true_socket,
-                server_hostname=server_hostname,
-                _context=true_ssl_context(protocol=SSL_PROTOCOL),
-            )
-        elif isinstance(sock, int) and true_ssl_context:
-            self.context = true_ssl_context(sock)
-
     def _set_dummy_methods(self):
         def dummy_method(*args, **kwargs):
             pass
@@ -127,7 +108,7 @@ class FakeSSLContext(SuperFakeSSLContext):
             setattr(self, m, dummy_method)
 
     @staticmethod
-    def wrap_socket(sock=sock, *args, **kwargs):
+    def wrap_socket(sock, *args, **kwargs):
         sock.kwargs = kwargs
         sock._secure_socket = True
         return sock
@@ -138,10 +119,6 @@ class FakeSSLContext(SuperFakeSSLContext):
         ssl_obj._host = kwargs["server_hostname"]
         return ssl_obj
 
-    def __getattr__(self, name):
-        if self.sock is not None:
-            return getattr(self.sock, name)
-
 
 def create_connection(address, timeout=None, source_address=None):
     s = socket.socket(socket.AF_INET, socket.SOCK_STREAM, socket.IPPROTO_TCP)
@@ -393,18 +370,15 @@ class MocketSocket:
                 self.true_socket.connect((host, port))
             self.true_socket.sendall(data, *args, **kwargs)
             encoded_response = b""
-            # https://github.com/kennethreitz/requests/blob/master/tests/testserver/server.py#L13
+            # https://github.com/kennethreitz/requests/blob/master/tests/testserver/server.py#L12
             while True:
-                if (
-                    not select.select([self.true_socket], [], [], 0.1)[0]
-                    and encoded_response
-                ):
+                more_to_read = select.select([self.true_socket], [], [], 0.1)[0]
+                if not more_to_read and encoded_response:
                     break
-                recv = self.true_socket.recv(self._buflen)
-
-                if not recv and encoded_response:
+                new_content = self.true_socket.recv(self._buflen)
+                if not new_content:
                     break
-                encoded_response += recv
+                encoded_response += new_content
 
             # dump the resulting dictionary to a JSON file
             if Mocket.get_truesocket_recording_dir():
@@ -565,8 +539,6 @@ class Mocket:
         if pyopenssl_override:  # pragma: no cover
             # Take out the pyopenssl version - use the default implementation
             extract_from_urllib3()
-        if aiohttp_make_ssl_context_cache_clear:  # pragma: no cover
-            aiohttp_make_ssl_context_cache_clear()
 
     @staticmethod
     def disable():
@@ -603,8 +575,6 @@ class Mocket:
         if pyopenssl_override:  # pragma: no cover
             # Put the pyopenssl version back in place
             inject_into_urllib3()
-        if aiohttp_make_ssl_context_cache_clear:  # pragma: no cover
-            aiohttp_make_ssl_context_cache_clear()
 
     @classmethod
     def get_namespace(cls):
